# PBEM

PBEM is a library to solve the periodic Helmholtz problem, it supports one periodic dimension in 2D and two periodic dimensions in 3D. 

<!-- TODO -->
## Installation 
Bempp-cl can be installed from this repository by running:
```bash
python setup.py install
```

## Documentation
The library is really simple to use, to familiarize yourself with it there are two notebooks with applications for the 2D and 3D implementations.

## Testing
The functionality of the library can be tested by running the notebooks for 2D and 3D.

## Getting help
Errors in the library should be added to the [GitHub issue tracker](https://github.com/PBEM-IMT3810/issues).

Questions about the library and its use can be asked to [Danilo Aballay](danilo.aballay@uc.cl) or [Vicente Iligaray](vicente.iligaray@uc.cl).